@@ -3,8 +3,12 @@ matches <- function(query, target, return.matches=FALSE) {
   if (!all(unlist(lapply(target, class)) == 'jobjRef'))
     stop("targets must be a list of IAtomContainer objects or a single IAtomContainer object")
 
+  dcob <- .jcall("org/openscience/cdk/DefaultChemObjectBuilder",
+                 "Lorg/openscience/cdk/interfaces/IChemObjectBuilder;",
+                 "getInstance")
+
   ## make an SQT
-  sqt <- new(J("org/openscience/cdk/smiles/smarts/SMARTSQueryTool"), query)
+  sqt <- new(J("org/openscience/cdk/smiles/smarts/SMARTSQueryTool"), query, dcob)
   matchings <- unlist(lapply(target, function(z) sqt$matches(z)))
 
   matchings <- lapply(target, function(z) {
