@@ -2,7 +2,11 @@ test.is.aromatic <- function()
 {
   m <- parse.smiles('c1ccccc1CC')[[1]]
   x <- unlist(lapply(get.atoms(m), is.aromatic))
-  checkEquals(6, length(which(x)))
+  checkEquals(0, length(which(x)))
+  do.typing(m)
+  do.aromaticity(m)
+  x <- unlist(lapply(get.atoms(m), is.aromatic))
+  checkEquals(6, length(which(x)))  
 }
 
 test.get.hcount <- function() {
